这是prefix

## 1公司介绍

苹果公司是生产手机的公司

### 1-1学术文章

这是一篇学术文章，研究了苹果公司的发展史。

#### 1-1-1财报

这是苹果公司2024年财报。

#### 1-1-2时事新闻

苹果公司今日退出新品

| **序号** |   **合作机构**   | **类别** |         牵头/参与          |
|--------|--------------|--------|------------------------|
| 1      | IEEE P2807.1 | 国际标准   | 《知识图谱技术要求与测试评估规范》      |
| 2      | IEEE P2807.2 | 国际标准   | 《金融知识图谱应用指南》           |
| 3      | 信标委          | 国标     | 《畜牧知识图谱构建与应用要求》        |
| 4      | 信标委          | 国标     | 《信息技术 人工智能 知识图谱存储技术要求》 |
| 5      | CCSA         | 行标     | 《基于知识图谱的电信运营商数据管理技术要求》 |
| 6      | CCSA         | 行标     | 《基于人工智能的知识图谱系统技术要求》    |
| 7      | CCSA         | 团标     | 《基于人工智能的知识图谱系统技术框架》    |
| 8      | AllA         | 团标     | 《金融知识图谱系统技术要求》         |
| 9      | 金科联盟         | 团标     | 《金融知识图谱构建和应用指南》        |
| 10     | 支付清算协会       | 团标     | 《基于知识图谱的收单风险防控技术框架》    |
| 11     | 中电标协         | 团标     | 《金融知识图谱产品检测技术规范》       |
| 12     | 金科联盟         | 研究报告   | 《知识图谱在金融领域的应用研究》       |
| 13     | 电子四院         | 白皮书    | 《知识图谱互联互通白皮书》          |

## 2足球新闻

皇家马德里夺得欧冠冠军。

### 2-1小说介绍

东邪西毒是射雕英雄传的任务

### 2-2行程安排

先去参加会议，然后回家。
